.. vim: set fileencoding=utf-8 :
.. author: Amir Mohammadi <amir.mohammadi@idiap.ch>

.. _bob.fusion.base:

=========================================================================
 Score Fusion in Biometric Recognition and Presentation Attack Detection
=========================================================================

.. todolist::

This package provides open source tools to run comparable and reproducible
score fusion in biometric and presentation attack detection experiments using
various algorithms. It provides several algorithms and scripts to be used for
running and reporting fusion experiments. It is written to be tightly
integrated with bob_ and scikit-learn_.

If you use this package, please cite the following publication::

    @inproceedings{bob2017,
      author = {A. Anjos AND M. G\"unther AND T. de Freitas Pereira AND
                P. Korshunov AND A. Mohammadi AND S. Marcel},
      title = {Continuously Reproducing Toolchains in Pattern Recognition and
               Machine Learning Experiments},
      year = {2017},
      month = aug,
      booktitle = {International Conference on Machine Learning (ICML)},
      url = {http://publications.idiap.ch/downloads/papers/2017/Anjos_ICML2017-2_2017.pdf}
    }


.. toctree::
   :maxdepth: 2

   guide
   py_api


.. include:: links.rst
